@@ -141,7 +141,7 @@
     <message>
         <location filename="mainwindow.cpp" line="224"/>
         <source>Fix missing dependencies...</source>
-        <translation type="unfinished"/>
+        <translation>Ispravljam nedostajuće zavisnosti... </translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="226"/>
@@ -171,12 +171,12 @@
     <message>
         <location filename="mainwindow.cpp" line="261"/>
         <source>About Codecs</source>
-        <translation type="unfinished"/>
+        <translation>O kodecima</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="262"/>
         <source>Codecs</source>
-        <translation type="unfinished"/>
+        <translation>Kodeci</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="262"/>
@@ -220,7 +220,7 @@
     <message>
         <location filename="main.cpp" line="54"/>
         <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
-        <translation type="unfinished"/>
+        <translation>Još jedna aplikacija za upravljanje paketima ( poput Synaptica ili apt-get), je već pokrenuta. Molim najprije zatvorite tu aplikaciju</translation>
     </message>
     <message>
         <location filename="main.cpp" line="67"/>
